@@ -4,8 +4,7 @@
 import hashlib
 import io
 import os
-import urllib.request, urllib.error, urllib.parse
-from contextlib import closing
+import requests
 from datetime import datetime
 
 from ..messages import *
@@ -95,8 +94,7 @@ def updateByManifest(path, dryRun=False):
         warn("Couldn't find local manifest file.\n{0}", e)
         return False
     try:
-        with closing(urllib.request.urlopen(ghPrefix + "manifest.txt")) as fh:
-            remoteManifest = [str(line, encoding="utf-8") for line in fh]
+        remoteManifest = requests.get(ghPrefix + "manifest.txt").text.splitlines()
     except Exception as e:
         warn("Couldn't download remote manifest file.\n{0}", e)
         return False
@@ -140,8 +138,7 @@ def updateByManifest(path, dryRun=False):
             remotePath = ghPrefix + filePath
             localPath = localizePath(path, filePath)
             try:
-                with closing(urllib.request.urlopen(remotePath)) as fh:
-                    newFile = str(fh.read(), encoding="utf-8")
+                newFile = requests.get(remotePath).text
             except Exception as e:
                 warn("Couldn't download file '{0}'.\n{1}", remotePath, e)
                 return False
